==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/component/PaymentProcessorComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component;

import javax.enterprise.context.RequestScoped;
import javax.enterprise.inject.Default;
import javax.inject.Inject;

import org.apache.webbeans.test.annotation.binding.Check;

@RequestScoped
@Default
public class PaymentProcessorComponent
{
    private IPayment paymentCheck;
    private IPayment paymentMoney;

    @Inject
    public void setPaymentCheck(@Check(type = "CHECK") IPayment payment)
    {
        this.paymentCheck = payment;

    }

    @Inject
    public void setPaymentMoney(@Check(type = "MONEY") IPayment payment)
    {
        this.paymentMoney = payment;
    }

    public IPayment getPaymentCheck()
    {
        return paymentCheck;
    }

    public IPayment getPaymentMoney()
    {
        return paymentMoney;
    }

}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/component/PaymentProcessorComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.component;

import jakarta.enterprise.context.RequestScoped;
import jakarta.enterprise.inject.Default;
import jakarta.inject.Inject;

import org.apache.webbeans.test.annotation.binding.Check;

@RequestScoped
@Default
public class PaymentProcessorComponent
{
    private IPayment paymentCheck;
    private IPayment paymentMoney;

    @Inject
    public void setPaymentCheck(@Check(type = "CHECK") IPayment payment)
    {
        this.paymentCheck = payment;

    }

    @Inject
    public void setPaymentMoney(@Check(type = "MONEY") IPayment payment)
    {
        this.paymentMoney = payment;
    }

    public IPayment getPaymentCheck()
    {
        return paymentCheck;
    }

    public IPayment getPaymentMoney()
    {
        return paymentMoney;
    }

}
